#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
@Author : bGZo
@Date : 2025-07-27
@Links : https://github.com/bGZo
"""

import requests

from src.cnblog.api_endpoints import USER
from src.cnblog.client import CnblogClient


def get_current_user_info() -> dict:
    client = CnblogClient()
    response = client.session.get(USER)
    if response.status_code == 200:
        return response.json()
    else:
        response.raise_for_status()  # Raise an error for bad responses

if __name__ == '__main__':
    try:
        user_info = get_current_user_info()
        print(user_info)
    except requests.RequestException as e:
        print(f"An error occurred: {e}")


#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
@Author : bGZo
@Date : 2025-07-29
@Links : https://github.com/bGZo
"""
BASE_URL = "https://api.bgm.tv"

#Users
USER_CURRENT = f"{BASE_URL}/v0/me"

# Collection API Endpoints
COLLECTIONS_UPSERT = f"{BASE_URL}/v0/users/-/collections/%s"
# https://api.bgm.tv/v0/users/dandelion_fs/collections?subject_type&type&limit=1&offset=0
COLLECTIONS_QUERY_USERS = f"{BASE_URL}/v0/users/%s/collections"

# Subject API Endpoints
SUBJECT_QUERY = f"{BASE_URL}/v0/subjects/%s"
SUBJECT_CHARACTER_QUERY = f"{BASE_URL}/v0/subjects/%s/characters"



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
@Author : bGZo
@Date : 2025-07-27
@Links : https://github.com/bGZo
"""

import frontmatter
import sys
import html2text
from bs4 import BeautifulSoup
from markdownify import markdownify as md

"""
=========================================================================
From html to markdown
"""

# using BeautifulSoup to convert HTML to Markdown
def html_to_markdown_with_bs(html):
    soup = BeautifulSoup(html, 'html.parser')
    lines = []

    for elem in soup.recursiveChildGenerator():
        if elem.name:
            if elem.name in ['h1', 'h2', 'h3', 'h4', 'h5', 'h6']:
                level = int(elem.name[1])
                lines.append('#' * level + ' ' + elem.get_text(strip=True))
            elif elem.name == 'p':
                lines.append(elem.get_text(strip=True) + '\n')
            elif elem.name == 'a':
                lines.append(f"[{elem.get_text(strip=True)}]({elem.get('href')})")
            elif elem.name == 'ul':
                for li in elem.find_all('li'):
                    lines.append(f"- {li.get_text(strip=True)}")
            elif elem.name == 'ol':
                for idx, li in enumerate(elem.find_all('li'), 1):
                    lines.append(f"{idx}. {li.get_text(strip=True)}")
    return '\n'.join(lines)

# using markdownify to convert HTML to Markdown
def html_to_markdown_with_md(html: str) -> str:
    return md(html, strip=['a'])

# using html2text to convert HTML to Markdown
def html_to_markdown_with_html2text(html:str):
    # 使用 html2text 库将 HTML 转换为 Markdown
    return html2text.html2text(html)

"""
=========================================================================
"""


def read(path: str):
    # 读取并解析 Markdown 文件
    with open(path, 'r', encoding='utf-8') as f:
        post = frontmatter.load(f)
    # 获取 FrontMatter 和正文
    meta = post.metadata
    content = post.content
    return post


def dump_markdown_with_frontmatter(meta: dict, content: str) -> str:
    """
    输出带有FrontMatter的Markdown字符串
    :param meta: FrontMatter元数据（字典）
    :param content: Markdown正文内容
    :return: 合成后的Markdown字符串
    """
    post = frontmatter.Post(content, **meta)
    return frontmatter.dumps(post)




#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
@Author : bGZo
@Date : 2025-07-27
@Links : https://github.com/bGZo
"""
from dataclasses import dataclass

# Webpage Meta Template
@dataclass
class WebPage:
    title: str
    source: str
    created: str
    modified: str
    type: str



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
@Author : bGZo
@Date : 2025-07-28
@Links : https://github.com/bGZo
"""

from enum import Enum

class CollectionType(Enum):
    """
    https://bangumi.github.io/api/#/model-CollectionType
    1: 想看
    2: 看过
    3: 在看
    4: 搁置
    5: 抛弃
    """
    WANT = 1
    DONE = 2
    DOING = 3
    WAITING = 4
    CANCEL = 5

    @classmethod
    def from_value(cls, value):
        for item in cls:
            if item.value == value:
                return item
        raise ValueError(f"Invalid value for CollectionTypeEnum: {value}")

    @classmethod
    def all(cls) -> list[int]:
        return list(cls)

    @classmethod
    def get_name(cls, value) -> str:
        """
        根据 value 返回对应的收藏类型中文名
        """
        mapping = {
            cls.WANT.value: "想看",
            cls.DONE.value: "看过",
            cls.DOING.value: "正在看",
            cls.WAITING.value: "搁置",
            cls.CANCEL.value: "抛弃"
        }
        return mapping.get(value, "未知")

    @classmethod
    def get_name_en(cls, value) -> str:
        """
        根据 value 返回对应的收藏类型英文名
        """
        mapping = {
            cls.WANT.value: "want",
            cls.DONE.value: "done",
            cls.DOING.value: "doing",
            cls.WAITING.value: "waiting",
            cls.CANCEL.value: "canncel"
        }
        return mapping.get(value, "unknown")



class SubjectType(Enum):
    """
    via: https://bangumi.github.io/api/#model-SubjectType
    1 为 书籍
    2 为 动画
    3 为 音乐
    4 为 游戏
    6 为 三次元
    没有 5
    """
    BOOK = 1
    ANIME = 2
    MUSIC = 3
    GAME = 4
    REAL_LIFE = 6

    @classmethod
    def from_value(cls, value):
        for item in cls:
            if item.value == value:
                return item
        raise ValueError(f"Invalid value for SubjectTypeEnum: {value}")

    @classmethod
    def get_name(cls, value) -> str:
        """
        根据 value 返回对应的类型中文名
        """
        mapping = {
            cls.BOOK.value: "书籍",
            cls.ANIME.value: "动画",
            cls.MUSIC.value: "音乐",
            cls.GAME.value: "游戏",
            cls.REAL_LIFE.value: "三次元"
        }
        return mapping.get(value, "未知")

    @classmethod
    def get_name_en(cls, value) -> str:
        """
        根据 value 返回对应的类型中���名
        """
        mapping = {
            cls.BOOK.value: "book",
            cls.ANIME.value: "anime",
            cls.MUSIC.value: "music",
            cls.GAME.value: "game",
            cls.REAL_LIFE.value: "real"
        }
        return mapping.get(value, "unknown")



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
因为第三方API没有这个，所以只能用 传统 Cookie 的方式来获取时间线数据

@Author : bGZo
@Date : 2025-07-31
@Links : https://github.com/bGZo
"""

def get_user_timeline(username: str, limit: int = 30, offset: int = 0) -> list:
    """
    获取用户时间线数据
    :param username: 用户名
    :param limit: 每页数量
    :param offset: 偏移量
    :return: 时间线数据列表
    """
    # https://bgm.tv/user/dandelion_fs/timeline?page=12&ajax=1
    # 这里需要实现获取时间线的逻辑，可能需要使用 requests 库来发送 HTTP 请求
    # TODO 由于没有第三方API，这里假设有一个函数可以获取时间线数据
    raise NotImplementedError("时间线的逻辑")


#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
@Author : bGZo
@Date : 2025-07-27
@Links : https://github.com/bGZo
"""
BASE_URL = "https://api.cnblogs.com/api"

#Users
USER = f"{BASE_URL}/users"

# Bookmarks API Endpoints
BOOKMARK = f"{BASE_URL}/Bookmarks"
BOOKMARK_DELETE = f"{BASE_URL}/bookmarks/"

# Articles API Endpoints
# https://api.cnblogs.com/api/blogposts/9953718/body
BLOG_POST = f"{BASE_URL}/blogposts/%s/body"



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
@Author : bGZo
@Date : 2025-07-27
@Links : https://github.com/bGZo
"""
import re
import os

def output_content_to_file_path(file_dir: str, file_name: str, content: str, file_type: str = "md") -> str:
    output_path = output_file_path(file_dir, file_name, file_type)
    ensure_output_directory_exists(file_dir)
    with open(output_path, "w", encoding="utf-8") as f:
        f.write(content)
    return output_path


def output_file_path(file_dir: str, file_name: str, file_type: str = "md") -> str:
    return os.path.join(file_dir, f"~{file_name}.{file_type}")

def ensure_output_directory_exists(output_dir: str):
    if not os.path.exists(output_dir):
        os.makedirs(output_dir)
        print(f"Output directory '{output_dir}' created.")


def get_clean_filename(filename: str) -> str:
    try:
        filename = re.sub(r'[@…：.？，！\|｜【】\[\]:!“”《》_、「」#——<>:"/\\|\-。（）&•]', ' ', filename)
    except AttributeError:
        pass

    filename = re.sub(r'[ ]+', ' ', filename)
    filename = filename.strip()
    filename = re.sub(r' ', '-', filename)
    return filename



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
@Author : bGZo
@Date : 2025-07-28
@Links : https://github.com/bGZo
"""
from http.client import responses
from datetime import datetime

from src.bangumi.api_endpoints import COLLECTIONS_UPSERT, COLLECTIONS_QUERY_USERS
from src.bangumi.client import BangumiClient
from src.bangumi.entity import UserSubjectCollection, SlimSubjectV0, SubjectImages, SubjectTag


def mark_subject(subject_id: int, status: int, comment: str = "", tags: list[str] = None) -> bool:
    """
    Mark a subject with a specific status and optional comment and tags.

    :param subject_id: The ID of the subject to mark.
    :param status: The status to set for the subject (e.g., "collect", "wish", "do", "on_hold", "drop").
    :param comment: An optional comment about the subject.
    :param tags: An optional list of tags to associate with the subject.
    :return: A dictionary containing the response from the API.
    """
    # Implementation would go here
    if tags is None:
        tags = []
    client = BangumiClient()
    payload = {
        "type": status,
        "rate": 0,
        # "ep_status": 0,
        # "vol_status": 0,
        "comment": comment,
        "private": False,
        "tags": tags
    }

    response = client.session.post(COLLECTIONS_UPSERT % subject_id, json=payload)
    # Accept special for bgm
    if response.status_code == 202:
        return True
    else:
        print(f"Error marking subject: {response.status_code} {responses[response.status_code]}")
        print("Request payload:", payload)
        print("Response:", response.text)
        print(f"Error marking subject: {response.status_code} {responses[response.status_code]}")  # noqa: E501
        return False

def _dict_to_subject_images(d: dict) -> SubjectImages:
    return SubjectImages(**d)

def _dict_to_subject_tag_list(lst: list) -> list:
    return [SubjectTag(**tag) for tag in lst]

def _dict_to_slim_subject_v0(d: dict) -> SlimSubjectV0:
    return SlimSubjectV0(
        date=d.get("date"),
        images=_dict_to_subject_images(d["images"]),
        name=d["name"],
        name_cn=d["name_cn"],
        short_summary=d["short_summary"],
        tags=_dict_to_subject_tag_list(d.get("tags", [])),
        score=d["score"],
        type=d["type"],
        id=d["id"],
        eps=d["eps"],
        volumes=d["volumes"],
        collection_total=d["collection_total"],
        rank=d["rank"]
    )

def _dict_to_user_subject_collection(d: dict) -> UserSubjectCollection:
    return UserSubjectCollection(
        id=d.get("id", 0),
        updated_at=datetime.fromisoformat(d["updated_at"]),
        comment=d.get("comment"),
        tags=d.get("tags", []),
        vol_status=d["vol_status"],
        ep_status=d["ep_status"],
        subject_id=d["subject_id"],
        subject_type=d["subject_type"],
        rate=d["rate"],
        type=d["type"],
        private=d["private"],
        subject=_dict_to_slim_subject_v0(d["subject"])
    )

# TODO 包装返回全部的分页结果
def get_all_collections_by_pages(username: str, subject_type: int, collection_type: int, limit: int = 30, offset: int = 0) -> list[UserSubjectCollection]:
    """
    Get all collections for a specific subject type and type by pages.

    :param subject_type: The type of the subject (e.g., "anime", "book").
    :param collection_type: The collection type (e.g., "collect", "wish").
    :param limit: The number of items to return per page.
    :param offset: The offset for pagination.
    :return: A list of collections.
    """
    client = BangumiClient()
    response = client.session.get(
        COLLECTIONS_QUERY_USERS % username,
        params={
            "subject_type":subject_type,
            "type":collection_type,
            "limit": limit,
            "offset": offset
        }
    )
    if response.status_code == 200:
        result = response.json()
        return [
            _dict_to_user_subject_collection(item)
            for item in result.get("data", [])
        ]
    else:
        print(f"Error fetching collections page with response: {response.status_code} {responses[response.status_code]}")
        return []



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
上游定义： https://github.com/bangumi/server

@Author : bGZo
@Date : 2025-07-31
@Links : https://github.com/bGZo
"""

from dataclasses import dataclass
from typing import List, Optional, Any
from datetime import datetime

# https://github.com/bangumi/server/blob/fb44e70f9fac931fc29964cab9c5b5aec41433b0/web/res/image.go#L47
@dataclass
class SubjectImages:
    small: str
    grid: str
    large: str
    medium: str
    common: str

@dataclass
class PersonImages:
    small: str
    grid: str
    large: str
    medium: str
    common: str

# https://github.com/bangumi/server/blob/fb44e70f9fac931fc29964cab9c5b5aec41433b0/web/res/subject.go#L38-L42
@dataclass
class SubjectTag:
    # 根据实际结构补充字段
    name: str
    count: int
    total_cont: int


# https://github.com/bangumi/server/blob/fb44e70f9fac931fc29964cab9c5b5aec41433b0/web/res/subject.go#L66C1-L81C2
@dataclass
class SlimSubjectV0:
    date: Optional[str]
    images: SubjectImages  # 修正为 images
    name: str
    name_cn: str
    short_summary: str
    tags: List[SubjectTag]
    score: float
    type: int
    id: int
    eps: int
    volumes: int
    collection_total: int
    rank: int

# https://github.com/bangumi/server/blob/fb44e70f9fac931fc29964cab9c5b5aec41433b0/internal/collections/domain/collection/model.go#L34
@dataclass
class UserSubjectCollection:
    id: int
    updated_at: datetime
    comment: Optional[str]
    tags: List[str]
    vol_status: int
    ep_status: int
    subject_id: int
    subject_type: int
    rate: int
    type: int
    private: bool
    subject: SlimSubjectV0

@dataclass
class Rating:
    rank: Optional[int] = None
    total: Optional[int] = None
    count: Optional[int] = None
    score: Optional[float] = None

@dataclass
class SubjectCollectionStat:
    wish: int = 0
    collect: int = 0
    doing: int = 0
    on_hold: int = 0
    dropped: int = 0
    total: int = 0

@dataclass
class SubjectV0:
    date: Optional[str]
    platform: Optional[str]
    images: SubjectImages
    summary: str
    name: str
    name_cn: str
    tags: List[SubjectTag]
    infobox: Optional[List[Any]]
    rating: Optional[Rating]
    total_episodes: int
    collection: Optional[SubjectCollectionStat]
    id: int
    eps: int
    meta_tags: List[str]
    volumes: int
    series: bool
    locked: bool
    nsfw: bool
    type_id: int
    redirect: Optional[int]

@dataclass
class Actor:
    id: int
    name: str
    images: Optional[PersonImages] = None
    short_summary: str = ""
    career: List[str] = None
    type: int = 0
    locked: bool = False

@dataclass
class SubjectRelatedCharacter:
    images: PersonImages
    name: str
    relation: str
    actors: List[Actor]
    type: int
    id: int

# V0wiki 仅为 infobox 的类型别名，等价于 List[Any]
V0wiki = List[Any]
